@@ -6,6 +6,9 @@
   if (assertthat::is.error(res)) {
     res <- default
   }
+  if (target == "sdk_file_root") {
+    res <- path.expand(res)
+  }
   return(res)
 }
 
@@ -16,8 +19,11 @@
 #' @importFrom rappdirs app_dir
 .app_dir <- rappdirs::app_dir("awsjavasdk", version = packageVersion("awsjavasdk"))
 
-.onAttach <- function(libname, pkgname) {
+.onLoad <- function(libname, pkgname) {
   set_sdk_file_root()
+}
+
+.onAttach <- function(libname, pkgname) {
   if (!aws_sdk_present()) {
     packageStartupMessage(paste0("awsjavasdk did not detect its own copy of the AWS SDK. You must execute install_aws_sdk() in order to download the SDK and for the package to work as expected. If you've previously installed to a non-standard location, call set_sdk_file_root({{your alt_install root}}, confirm = TRUE) to point this package to that location and then run awsjavasdk::load_sdk()"))
   } else {
